import math

import numpy as np

from model.predict import make_prediction


def test_make_prediction(sample_input_data):
    # Given
    #JUST CHECKING IF RESULT VALUE IS A FLOAT...

    # When
    result = make_prediction(input_data=sample_input_data)

    # Then

    assert isinstance(result[0], np.float64)



import pandas as pd

from model import __version__ as _version
from model.config.core import config
from model.processing.data_manager import load_pipeline

pipeline_file_name = f"{config.app_config.pipeline_save_file}{_version}.pkl"
_pipe = load_pipeline(file_name=pipeline_file_name)

def make_prediction(
    input_data: pd.DataFrame,
):
    """Make a prediction using a saved model pipeline."""
    data = pd.DataFrame(input_data)
    print(data)
    return _pipe.predict(data)


import pandas as pd
from config.core import config
from pipeline import pipe
from processing.data_manager import load_dataset, save_pipeline
from sklearn.model_selection import train_test_split

def run_training() -> None:
    # read training data
    data = load_dataset(file_name=config.app_config.data_file)
    # divide train and test
    X_train, X_test, Y_train, Y_test = train_test_split(
        data[config.model_config.features],
        data[config.model_config.target],
        test_size=config.model_config.test_size,
        # we are setting the random seed here
        # for reproducibility
        random_state=config.model_config.random_state,
    )
    
    X_train = pd.DataFrame(X_train, columns = config.model_config.features)
    X_test = pd.DataFrame(X_test, columns = config.model_config.features)
    Y_train = pd.DataFrame(Y_train, columns = config.model_config.target)
    Y_test = pd.DataFrame(Y_test, columns = config.model_config.target)
    
    pipe.fit(X_train, Y_train.values.ravel())

    # persist trained model
    save_pipeline(pipeline_to_persist=pipe)

if __name__ == "__main__":
    run_training()